@@ -161,7 +161,7 @@ random_forest <- function(input_model=NA,
   }
 
   if (!identical(test, NA)) {
-    SetParamMat(p, "test", to_matrix(test))
+    SetParamMat(p, "test", to_matrix(test), TRUE)
   }
 
   if (!identical(test_labels, NA)) {
@@ -169,7 +169,7 @@ random_forest <- function(input_model=NA,
   }
 
   if (!identical(training, NA)) {
-    SetParamMat(p, "training", to_matrix(training))
+    SetParamMat(p, "training", to_matrix(training), TRUE)
   }
 
   if (!identical(warm_start, FALSE)) {
